@@ -2,6 +2,7 @@ from .client import TencentClient
 from tencentcloud.cfs.v20190719 import cfs_client as tencent_cfs_client, models
 from tencentcloud.cfs.v20190719 import models
 
+
 class CfsClient(TencentClient):
     def __init__(self, *args, **kwargs):
         super(CfsClient, self).__init__(*args, **kwargs)
@@ -20,3 +21,7 @@ class CfsClient(TencentClient):
     def describe_cfs_file_systems(self, **kwargs):
         req = models.DescribeCfsFileSystemsRequest()
         return self.do_request(self.client.DescribeCfsFileSystems, req, **kwargs)
+
+    def describe_mount_targets(self, **kwargs):
+        req = models.DescribeMountTargetsRequest()
+        return self.do_request(self.client.DescribeCfsFileSystems, req, **kwargs)
